# Canonical/Ubuntu specific testbed setup

# compatibility with old Jenkins testbeds for trusty
if grep -q trusty /etc/lsb-release; then apt-get update || (sleep 10; apt-get update); apt-get install -y build-essential; fi

# these packages really break tests, purge them if we use standard cloud images
# (on lcy01)
for p in unattended-upgrades lxd lxd-client snapd; do
    [ ! -d /usr/share/doc/$p ] || $(which eatmydata || true) apt-get purge --auto-remove -y $p
done

# work around broken PTMU; LP: #1572026, RT#90771
if type iptables >/dev/null 2>&1; then
    cat <<EOF > /etc/rc.local
#!/bin/sh
iptables -w -t mangle -A FORWARD -p tcp --tcp-flags SYN,RST SYN -j TCPMSS --clamp-mss-to-pmtu || true
EOF
    chmod 755 /etc/rc.local
    . /etc/rc.local
fi

# work around arm64 lockups (LP: #1531768)
if [ "$(uname -m)" = aarch64 ] && ! grep -q 'GRUB_CMDLINE_LINUX.*nohz-off' /etc/default/grub; then
    sed -i '/GRUB_CMDLINE_LINUX_DEFAULT/ s/=".*$/="nohz=off"/' /etc/default/grub
    update-grub
fi

# work around broken tty on ppc64el instances (LP: #1607075)
if [ "$(uname -m)" = ppc64le ] && [ "$(systemctl is-active keyboard-setup.service 2>/dev/null|| true)" = failed ]; then
    systemctl reset-failed keyboard-setup.service
    systemctl mask keyboard-setup.service
fi

# work around late urandom pool initialization (LP: #1622893)
if [ -d /run/systemd/system ] && systemd-detect-virt --quiet --vm; then
    mkdir -p /etc/systemd/system/systemd-random-seed.service.d/
    cat <<EOF > /etc/systemd/system/systemd-random-seed.service.d/fakeentropy.conf
[Service]
ExecStart=/usr/bin/perl -E 'open \$\$f, "/bin/bash" or die; open \$\$rnd, ">/dev/random" or die; for (\$\$i = 0; \$\$i < 10; ++\$\$i) {read \$\$f, \$\$d, 64; ioctl \$\$rnd, 0x40085203, pack("ii", 64*8, 64) . \$\$d}'
EOF
fi
